@@ -493,8 +493,7 @@ class Quantity(PrettyIPython, SharedRegistryObject):
         return self._dimensionality
 
     def check(self, dimension):
-        """Return true if the quantity's dimension matches passed dimension.
-        """
+        """Return true if the quantity's dimension matches passed dimension."""
         return self.dimensionality == self._REGISTRY.get_dimensionality(dimension)
 
     @classmethod
@@ -569,7 +568,7 @@ class Quantity(PrettyIPython, SharedRegistryObject):
         return self._REGISTRY.get_compatible_units(self._units)
 
     def is_compatible_with(self, other, *contexts, **ctx_kwargs):
-        """ check if the other object is compatible
+        """check if the other object is compatible
 
         Parameters
         ----------
@@ -740,7 +739,7 @@ class Quantity(PrettyIPython, SharedRegistryObject):
         return newq
 
     def to_compact(self, unit=None):
-        """"Return Quantity rescaled to compact, human-readable units.
+        """ "Return Quantity rescaled to compact, human-readable units.
 
         To get output in terms of a different unit, use the unit parameter.
 
@@ -806,9 +805,9 @@ class Quantity(PrettyIPython, SharedRegistryObject):
             unit_str, unit_power = units[0]
 
         if unit_power > 0:
-            power = int(math.floor(math.log10(abs(magnitude)) / unit_power / 3)) * 3
+            power = math.floor(math.log10(abs(magnitude)) / unit_power / 3) * 3
         else:
-            power = int(math.ceil(math.log10(abs(magnitude)) / unit_power / 3)) * 3
+            power = math.ceil(math.log10(abs(magnitude)) / unit_power / 3) * 3
 
         index = bisect.bisect_left(SI_powers, power)
 
@@ -1386,15 +1385,19 @@ class Quantity(PrettyIPython, SharedRegistryObject):
             if is_duck_array_type(type(getattr(other, "_magnitude", other))):
                 # arrays are refused as exponent, because they would create
                 # len(array) quantities of len(set(array)) different units
-                # unless the base is dimensionless.
+                # unless the base is dimensionless. Ensure dimensionless
+                # units are reduced to "dimensionless".
+                # Note: this will strip Units of degrees or radians from Quantity
                 if self.dimensionless:
                     if getattr(other, "dimensionless", False):
-                        self._magnitude **= other.m_as("")
+                        self._magnitude = self.m_as("") ** other.m_as("")
+                        self._units = self.UnitsContainer()
                         return self
                     elif not getattr(other, "dimensionless", True):
                         raise DimensionalityError(other._units, "dimensionless")
                     else:
-                        self._magnitude **= other
+                        self._magnitude = self.m_as("") ** other
+                        self._units = self.UnitsContainer()
                         return self
                 elif np.size(other) > 1:
                     raise DimensionalityError(
@@ -1444,13 +1447,20 @@ class Quantity(PrettyIPython, SharedRegistryObject):
                 # arrays are refused as exponent, because they would create
                 # len(array) quantities of len(set(array)) different units
                 # unless the base is dimensionless.
+                # Note: this will strip Units of degrees or radians from Quantity
                 if self.dimensionless:
                     if getattr(other, "dimensionless", False):
-                        return self.__class__(self.m ** other.m_as(""))
+                        return self.__class__(
+                            self._convert_magnitude_not_inplace(self.UnitsContainer())
+                            ** other.m_as("")
+                        )
                     elif not getattr(other, "dimensionless", True):
                         raise DimensionalityError(other._units, "dimensionless")
                     else:
-                        return self.__class__(self.m ** other)
+                        return self.__class__(
+                            self._convert_magnitude_not_inplace(self.UnitsContainer())
+                            ** other
+                        )
                 elif np.size(other) > 1:
                     raise DimensionalityError(
                         self._units,
@@ -1577,7 +1587,7 @@ class Quantity(PrettyIPython, SharedRegistryObject):
 
     @check_implemented
     def compare(self, other, op):
-        if not isinstance(other, self.__class__):
+        if not isinstance(other, Quantity):
             if self.dimensionless:
                 return op(
                     self._convert_magnitude_not_inplace(self.UnitsContainer()), other
@@ -1598,6 +1608,13 @@ class Quantity(PrettyIPython, SharedRegistryObject):
             else:
                 raise ValueError("Cannot compare Quantity and {}".format(type(other)))
 
+        # Registry equality check based on util.SharedRegistryObject
+        if self._REGISTRY is not other._REGISTRY:
+            mess = "Cannot operate with {} and {} of different registries."
+            raise ValueError(
+                mess.format(self.__class__.__name__, other.__class__.__name__)
+            )
+
         if self._units == other._units:
             return op(self._magnitude, other._magnitude)
         if self.dimensionality != other.dimensionality:
@@ -1774,7 +1791,7 @@ class Quantity(PrettyIPython, SharedRegistryObject):
 
     @method_wraps("prod")
     def prod(self, *args, **kwargs):
-        """ Return the product of quantity elements over a given axis
+        """Return the product of quantity elements over a given axis
 
         Wraps np.prod().
         """
@@ -1879,12 +1896,22 @@ class Quantity(PrettyIPython, SharedRegistryObject):
 
     def tolist(self):
         units = self._units
-        return [
-            self.__class__(value, units).tolist()
-            if isinstance(value, list)
-            else self.__class__(value, units)
-            for value in self._magnitude.tolist()
-        ]
+
+        try:
+            values = self._magnitude.tolist()
+            if not isinstance(values, list):
+                return self.__class__(values, units)
+
+            return [
+                self.__class__(value, units).tolist()
+                if isinstance(value, list)
+                else self.__class__(value, units)
+                for value in self._magnitude.tolist()
+            ]
+        except AttributeError:
+            raise AttributeError(
+                f"Magnitude '{type(self._magnitude).__name__}' does not support tolist."
+            )
 
     # Measurement support
     def plus_minus(self, error, relative=False):
@@ -1928,8 +1955,7 @@ class Quantity(PrettyIPython, SharedRegistryObject):
         return [u for u in self._units if u.startswith("delta_")]
 
     def _has_compatible_delta(self, unit: str) -> bool:
-        """"Check if Quantity object has a delta_unit that is compatible with unit
-        """
+        """ "Check if Quantity object has a delta_unit that is compatible with unit"""
         deltas = self._get_delta_units()
         if "delta_" + unit in deltas:
             return True
@@ -1940,8 +1966,7 @@ class Quantity(PrettyIPython, SharedRegistryObject):
         )
 
     def _ok_for_muldiv(self, no_offset_units=None):
-        """Checks if Quantity object can be multiplied or divided
-        """
+        """Checks if Quantity object can be multiplied or divided"""
 
         is_ok = True
         if no_offset_units is None:
