@@ -1,11 +1,10 @@
 import copy
 import math
 import pprint
-import unittest
 
 import pytest
 
-from pint import Context, DimensionalityError, UnitRegistry
+from pint import Context, DimensionalityError, UnitRegistry, get_application_registry
 from pint.compat import np
 from pint.testsuite import QuantityTestCase, helpers
 from pint.unit import UnitsContainer
@@ -16,109 +15,108 @@ ureg = UnitRegistry()
 
 class TestIssues(QuantityTestCase):
 
-    FORCE_NDARRAY = False
+    kwargs = dict(autoconvert_offset_to_baseunit=False)
 
-    def setup(self):
-        self.ureg.autoconvert_offset_to_baseunit = False
-
-    @unittest.expectedFailure
+    @pytest.mark.xfail
     def test_issue25(self):
         x = ParserHelper.from_string("10 %")
-        self.assertEqual(x, ParserHelper(10, {"%": 1}))
+        assert x == ParserHelper(10, {"%": 1})
         x = ParserHelper.from_string("10 ‰")
-        self.assertEqual(x, ParserHelper(10, {"‰": 1}))
+        assert x == ParserHelper(10, {"‰": 1})
         ureg.define("percent = [fraction]; offset: 0 = %")
         ureg.define("permille = percent / 10 = ‰")
         x = ureg.parse_expression("10 %")
-        self.assertEqual(x, ureg.Quantity(10, {"%": 1}))
+        assert x == ureg.Quantity(10, {"%": 1})
         y = ureg.parse_expression("10 ‰")
-        self.assertEqual(y, ureg.Quantity(10, {"‰": 1}))
-        self.assertEqual(x.to("‰"), ureg.Quantity(1, {"‰": 1}))
+        assert y == ureg.Quantity(10, {"‰": 1})
+        assert x.to("‰") == ureg.Quantity(1, {"‰": 1})
 
     def test_issue29(self):
         t = 4 * ureg("mW")
-        self.assertEqual(t.magnitude, 4)
-        self.assertEqual(t._units, UnitsContainer(milliwatt=1))
-        self.assertEqual(t.to("joule / second"), 4e-3 * ureg("W"))
+        assert t.magnitude == 4
+        assert t._units == UnitsContainer(milliwatt=1)
+        assert t.to("joule / second") == 4e-3 * ureg("W")
 
-    @unittest.expectedFailure
-    @helpers.requires_numpy()
+    @pytest.mark.xfail
+    @helpers.requires_numpy
     def test_issue37(self):
         x = np.ma.masked_array([1, 2, 3], mask=[True, True, False])
         q = ureg.meter * x
-        self.assertIsInstance(q, ureg.Quantity)
+        assert isinstance(q, ureg.Quantity)
         np.testing.assert_array_equal(q.magnitude, x)
-        self.assertEqual(q.units, ureg.meter.units)
+        assert q.units == ureg.meter.units
         q = x * ureg.meter
-        self.assertIsInstance(q, ureg.Quantity)
+        assert isinstance(q, ureg.Quantity)
         np.testing.assert_array_equal(q.magnitude, x)
-        self.assertEqual(q.units, ureg.meter.units)
+        assert q.units == ureg.meter.units
 
         m = np.ma.masked_array(2 * np.ones(3, 3))
         qq = q * m
-        self.assertIsInstance(qq, ureg.Quantity)
+        assert isinstance(qq, ureg.Quantity)
         np.testing.assert_array_equal(qq.magnitude, x * m)
-        self.assertEqual(qq.units, ureg.meter.units)
+        assert qq.units == ureg.meter.units
         qq = m * q
-        self.assertIsInstance(qq, ureg.Quantity)
+        assert isinstance(qq, ureg.Quantity)
         np.testing.assert_array_equal(qq.magnitude, x * m)
-        self.assertEqual(qq.units, ureg.meter.units)
+        assert qq.units == ureg.meter.units
 
-    @unittest.expectedFailure
-    @helpers.requires_numpy()
+    @pytest.mark.xfail
+    @helpers.requires_numpy
     def test_issue39(self):
         x = np.matrix([[1, 2, 3], [1, 2, 3], [1, 2, 3]])
         q = ureg.meter * x
-        self.assertIsInstance(q, ureg.Quantity)
+        assert isinstance(q, ureg.Quantity)
         np.testing.assert_array_equal(q.magnitude, x)
-        self.assertEqual(q.units, ureg.meter.units)
+        assert q.units == ureg.meter.units
         q = x * ureg.meter
-        self.assertIsInstance(q, ureg.Quantity)
+        assert isinstance(q, ureg.Quantity)
         np.testing.assert_array_equal(q.magnitude, x)
-        self.assertEqual(q.units, ureg.meter.units)
+        assert q.units == ureg.meter.units
 
         m = np.matrix(2 * np.ones(3, 3))
         qq = q * m
-        self.assertIsInstance(qq, ureg.Quantity)
+        assert isinstance(qq, ureg.Quantity)
         np.testing.assert_array_equal(qq.magnitude, x * m)
-        self.assertEqual(qq.units, ureg.meter.units)
+        assert qq.units == ureg.meter.units
         qq = m * q
-        self.assertIsInstance(qq, ureg.Quantity)
+        assert isinstance(qq, ureg.Quantity)
         np.testing.assert_array_equal(qq.magnitude, x * m)
-        self.assertEqual(qq.units, ureg.meter.units)
+        assert qq.units == ureg.meter.units
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue44(self):
         x = 4.0 * ureg.dimensionless
         np.sqrt(x)
-        self.assertQuantityAlmostEqual(
+        helpers.assert_quantity_almost_equal(
             np.sqrt([4.0] * ureg.dimensionless), [2.0] * ureg.dimensionless
         )
-        self.assertQuantityAlmostEqual(
+        helpers.assert_quantity_almost_equal(
             np.sqrt(4.0 * ureg.dimensionless), 2.0 * ureg.dimensionless
         )
 
     def test_issue45(self):
         import math
 
-        self.assertAlmostEqual(math.sqrt(4 * ureg.m / ureg.cm), math.sqrt(4 * 100))
-        self.assertAlmostEqual(float(ureg.V / ureg.mV), 1000.0)
+        helpers.assert_quantity_almost_equal(
+            math.sqrt(4 * ureg.m / ureg.cm), math.sqrt(4 * 100)
+        )
+        helpers.assert_quantity_almost_equal(float(ureg.V / ureg.mV), 1000.0)
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue45b(self):
-        self.assertAlmostEqual(
+        helpers.assert_quantity_almost_equal(
             np.sin([np.pi / 2] * ureg.m / ureg.m),
             np.sin([np.pi / 2] * ureg.dimensionless),
         )
-        self.assertAlmostEqual(
+        helpers.assert_quantity_almost_equal(
             np.sin([np.pi / 2] * ureg.cm / ureg.m),
             np.sin([np.pi / 2] * ureg.dimensionless * 0.01),
         )
 
     def test_issue50(self):
         Q_ = ureg.Quantity
-        self.assertEqual(Q_(100), 100 * ureg.dimensionless)
-        self.assertEqual(Q_("100"), 100 * ureg.dimensionless)
+        assert Q_(100) == 100 * ureg.dimensionless
+        assert Q_("100") == 100 * ureg.dimensionless
 
     def test_issue52(self):
         u1 = UnitRegistry()
@@ -139,63 +137,69 @@ class TestIssues(QuantityTestCase):
             op.truediv,
             op.itruediv,
         ):
-            self.assertRaises(ValueError, fun, q1, q2)
+            with pytest.raises(ValueError):
+                fun(q1, q2)
 
     def test_issue54(self):
-        self.assertEqual((1 * ureg.km / ureg.m + 1).magnitude, 1001)
+        assert (1 * ureg.km / ureg.m + 1).magnitude == 1001
 
     def test_issue54_related(self):
-        self.assertEqual(ureg.km / ureg.m, 1000)
-        self.assertEqual(1000, ureg.km / ureg.m)
-        self.assertLess(900, ureg.km / ureg.m)
-        self.assertGreater(1100, ureg.km / ureg.m)
+        assert ureg.km / ureg.m == 1000
+        assert 1000 == ureg.km / ureg.m
+        assert 900 < ureg.km / ureg.m
+        assert 1100 > ureg.km / ureg.m
 
     def test_issue61(self):
         Q_ = ureg.Quantity
         for value in ({}, {"a": 3}, None):
-            self.assertRaises(TypeError, Q_, value)
-            self.assertRaises(TypeError, Q_, value, "meter")
-        self.assertRaises(ValueError, Q_, "", "meter")
-        self.assertRaises(ValueError, Q_, "")
+            with pytest.raises(TypeError):
+                Q_(value)
+            with pytest.raises(TypeError):
+                Q_(value, "meter")
+        with pytest.raises(ValueError):
+            Q_("", "meter")
+        with pytest.raises(ValueError):
+            Q_("")
 
     @helpers.requires_not_numpy()
     def test_issue61_notNP(self):
         Q_ = ureg.Quantity
         for value in ([1, 2, 3], (1, 2, 3)):
-            self.assertRaises(TypeError, Q_, value)
-            self.assertRaises(TypeError, Q_, value, "meter")
+            with pytest.raises(TypeError):
+                Q_(value)
+            with pytest.raises(TypeError):
+                Q_(value, "meter")
 
     def test_issue62(self):
         m = ureg("m**0.5")
-        self.assertEqual(str(m.units), "meter ** 0.5")
+        assert str(m.units) == "meter ** 0.5"
 
     def test_issue66(self):
-        self.assertEqual(
-            ureg.get_dimensionality(UnitsContainer({"[temperature]": 1})),
-            UnitsContainer({"[temperature]": 1}),
+        assert ureg.get_dimensionality(
+            UnitsContainer({"[temperature]": 1})
+        ) == UnitsContainer({"[temperature]": 1})
+        assert ureg.get_dimensionality(ureg.kelvin) == UnitsContainer(
+            {"[temperature]": 1}
         )
-        self.assertEqual(
-            ureg.get_dimensionality(ureg.kelvin), UnitsContainer({"[temperature]": 1})
-        )
-        self.assertEqual(
-            ureg.get_dimensionality(ureg.degC), UnitsContainer({"[temperature]": 1})
+        assert ureg.get_dimensionality(ureg.degC) == UnitsContainer(
+            {"[temperature]": 1}
         )
 
     def test_issue66b(self):
-        self.assertEqual(
-            ureg.get_base_units(ureg.kelvin),
-            (1.0, ureg.Unit(UnitsContainer({"kelvin": 1}))),
+        assert ureg.get_base_units(ureg.kelvin) == (
+            1.0,
+            ureg.Unit(UnitsContainer({"kelvin": 1})),
         )
-        self.assertEqual(
-            ureg.get_base_units(ureg.degC),
-            (1.0, ureg.Unit(UnitsContainer({"kelvin": 1}))),
+        assert ureg.get_base_units(ureg.degC) == (
+            1.0,
+            ureg.Unit(UnitsContainer({"kelvin": 1})),
         )
 
     def test_issue69(self):
         q = ureg("m").to(ureg("in"))
-        self.assertEqual(q, ureg("m").to("in"))
+        assert q == ureg("m").to("in")
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue74(self):
         v1 = np.asarray([1.0, 2.0, 3.0])
         v2 = np.asarray([3.0, 2.0, 1.0])
@@ -217,7 +221,7 @@ class TestIssues(QuantityTestCase):
         np.testing.assert_array_equal(q1 <= q2s, v1 <= v2s)
         np.testing.assert_array_equal(q1 >= q2s, v1 >= v2s)
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue75(self):
         v1 = np.asarray([1.0, 2.0, 3.0])
         v2 = np.asarray([3.0, 2.0, 1.0])
@@ -238,7 +242,7 @@ class TestIssues(QuantityTestCase):
         acc = (5.0 * ureg("m/s/s")).plus_minus(0.25)
         tim = (37.0 * ureg("s")).plus_minus(0.16)
         dis = acc * tim ** 2 / 2
-        self.assertEqual(dis.value, acc.value * tim.value ** 2 / 2)
+        assert dis.value == acc.value * tim.value ** 2 / 2
 
     def test_issue85(self):
 
@@ -251,7 +255,7 @@ class TestIssues(QuantityTestCase):
         boltmk = 1.380649e-23 * ureg.J / ureg.K
         vb = 2.0 * boltmk * T / m
 
-        self.assertQuantityAlmostEqual(va.to_base_units(), vb.to_base_units())
+        helpers.assert_quantity_almost_equal(va.to_base_units(), vb.to_base_units())
 
     def test_issue86(self):
         ureg = self.ureg
@@ -273,22 +277,22 @@ class TestIssues(QuantityTestCase):
 
         k1m, k1u = parts(k1)
 
-        self.assertEqual(parts(q2 * q3), (q2m * q3m, q2u * q3u))
-        self.assertEqual(parts(q2 / q3), (q2m / q3m, q2u / q3u))
-        self.assertEqual(parts(q3 * q2), (q3m * q2m, q3u * q2u))
-        self.assertEqual(parts(q3 / q2), (q3m / q2m, q3u / q2u))
-        self.assertEqual(parts(q2 ** 1), (q2m ** 1, q2u ** 1))
-        self.assertEqual(parts(q2 ** -1), (q2m ** -1, q2u ** -1))
-        self.assertEqual(parts(q2 ** 2), (q2m ** 2, q2u ** 2))
-        self.assertEqual(parts(q2 ** -2), (q2m ** -2, q2u ** -2))
+        assert parts(q2 * q3) == (q2m * q3m, q2u * q3u)
+        assert parts(q2 / q3) == (q2m / q3m, q2u / q3u)
+        assert parts(q3 * q2) == (q3m * q2m, q3u * q2u)
+        assert parts(q3 / q2) == (q3m / q2m, q3u / q2u)
+        assert parts(q2 ** 1) == (q2m ** 1, q2u ** 1)
+        assert parts(q2 ** -1) == (q2m ** -1, q2u ** -1)
+        assert parts(q2 ** 2) == (q2m ** 2, q2u ** 2)
+        assert parts(q2 ** -2) == (q2m ** -2, q2u ** -2)
 
-        self.assertEqual(parts(q1 * q3), (k1m * q3m, k1u * q3u))
-        self.assertEqual(parts(q1 / q3), (k1m / q3m, k1u / q3u))
-        self.assertEqual(parts(q3 * q1), (q3m * k1m, q3u * k1u))
-        self.assertEqual(parts(q3 / q1), (q3m / k1m, q3u / k1u))
-        self.assertEqual(parts(q1 ** -1), (k1m ** -1, k1u ** -1))
-        self.assertEqual(parts(q1 ** 2), (k1m ** 2, k1u ** 2))
-        self.assertEqual(parts(q1 ** -2), (k1m ** -2, k1u ** -2))
+        assert parts(q1 * q3) == (k1m * q3m, k1u * q3u)
+        assert parts(q1 / q3) == (k1m / q3m, k1u / q3u)
+        assert parts(q3 * q1) == (q3m * k1m, q3u * k1u)
+        assert parts(q3 / q1) == (q3m / k1m, q3u / k1u)
+        assert parts(q1 ** -1) == (k1m ** -1, k1u ** -1)
+        assert parts(q1 ** 2) == (k1m ** 2, k1u ** 2)
+        assert parts(q1 ** -2) == (k1m ** -2, k1u ** -2)
 
     def test_issues86b(self):
         ureg = self.ureg
@@ -299,31 +303,31 @@ class TestIssues(QuantityTestCase):
         v1 = 2 * ureg.k * T1 / m
         v2 = 2 * ureg.k * T2 / m
 
-        self.assertQuantityAlmostEqual(v1, v2)
-        self.assertQuantityAlmostEqual(v1, v2.to_base_units())
-        self.assertQuantityAlmostEqual(v1.to_base_units(), v2)
-        self.assertQuantityAlmostEqual(v1.to_base_units(), v2.to_base_units())
+        helpers.assert_quantity_almost_equal(v1, v2)
+        helpers.assert_quantity_almost_equal(v1, v2.to_base_units())
+        helpers.assert_quantity_almost_equal(v1.to_base_units(), v2)
+        helpers.assert_quantity_almost_equal(v1.to_base_units(), v2.to_base_units())
 
-    @unittest.expectedFailure
+    @pytest.mark.xfail
     def test_issue86c(self):
         ureg = self.ureg
         ureg.autoconvert_offset_to_baseunit = True
         T = ureg.degC
         T = 100.0 * T
-        self.assertQuantityAlmostEqual(ureg.k * 2 * T, ureg.k * (2 * T))
+        helpers.assert_quantity_almost_equal(ureg.k * 2 * T, ureg.k * (2 * T))
 
     def test_issue93(self):
         x = 5 * ureg.meter
-        self.assertIsInstance(x.magnitude, int)
+        assert isinstance(x.magnitude, int)
         y = 0.1 * ureg.meter
-        self.assertIsInstance(y.magnitude, float)
+        assert isinstance(y.magnitude, float)
         z = 5 * ureg.meter
-        self.assertIsInstance(z.magnitude, int)
+        assert isinstance(z.magnitude, int)
         z += y
-        self.assertIsInstance(z.magnitude, float)
+        assert isinstance(z.magnitude, float)
 
-        self.assertQuantityAlmostEqual(x + y, 5.1 * ureg.meter)
-        self.assertQuantityAlmostEqual(z, 5.1 * ureg.meter)
+        helpers.assert_quantity_almost_equal(x + y, 5.1 * ureg.meter)
+        helpers.assert_quantity_almost_equal(z, 5.1 * ureg.meter)
 
     def test_issue104(self):
 
@@ -339,40 +343,40 @@ class TestIssues(QuantityTestCase):
 
             return total
 
-        self.assertQuantityAlmostEqual(summer(x), ureg.Quantity(3, "meter"))
-        self.assertQuantityAlmostEqual(x[0], ureg.Quantity(1, "meter"))
-        self.assertQuantityAlmostEqual(summer(y), ureg.Quantity(3, "meter"))
-        self.assertQuantityAlmostEqual(y[0], ureg.Quantity(1, "meter"))
+        helpers.assert_quantity_almost_equal(summer(x), ureg.Quantity(3, "meter"))
+        helpers.assert_quantity_almost_equal(x[0], ureg.Quantity(1, "meter"))
+        helpers.assert_quantity_almost_equal(summer(y), ureg.Quantity(3, "meter"))
+        helpers.assert_quantity_almost_equal(y[0], ureg.Quantity(1, "meter"))
 
     def test_issue105(self):
 
         func = ureg.parse_unit_name
         val = list(func("meter"))
-        self.assertEqual(list(func("METER")), [])
-        self.assertEqual(val, list(func("METER", False)))
+        assert list(func("METER")) == []
+        assert val == list(func("METER", False))
 
         for func in (ureg.get_name, ureg.parse_expression):
             val = func("meter")
-            with self.assertRaises(AttributeError):
+            with pytest.raises(AttributeError):
                 func("METER")
-            self.assertEqual(val, func("METER", False))
+            assert val == func("METER", False)
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue127(self):
         q = [1.0, 2.0, 3.0, 4.0] * self.ureg.meter
         q[0] = np.nan
-        self.assertNotEqual(q[0], 1.0)
-        self.assertTrue(math.isnan(q[0].magnitude))
+        assert q[0] != 1.0
+        assert math.isnan(q[0].magnitude)
         q[1] = float("NaN")
-        self.assertNotEqual(q[1], 2.0)
-        self.assertTrue(math.isnan(q[1].magnitude))
+        assert q[1] != 2.0
+        assert math.isnan(q[1].magnitude)
 
     def test_issue170(self):
         Q_ = UnitRegistry().Quantity
         q = Q_("1 kHz") / Q_("100 Hz")
         iq = int(q)
-        self.assertEqual(iq, 10)
-        self.assertIsInstance(iq, int)
+        assert iq == 10
+        assert isinstance(iq, int)
 
     def test_angstrom_creation(self):
         ureg.Quantity(2, "Å")
@@ -383,75 +387,75 @@ class TestIssues(QuantityTestCase):
     def test_micro_creation(self):
         ureg.Quantity(2, "µm")
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue171_real_imag(self):
         qr = [1.0, 2.0, 3.0, 4.0] * self.ureg.meter
         qi = [4.0, 3.0, 2.0, 1.0] * self.ureg.meter
         q = qr + 1j * qi
-        self.assertQuantityEqual(q.real, qr)
-        self.assertQuantityEqual(q.imag, qi)
+        helpers.assert_quantity_equal(q.real, qr)
+        helpers.assert_quantity_equal(q.imag, qi)
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue171_T(self):
         a = np.asarray([[1.0, 2.0, 3.0, 4.0], [4.0, 3.0, 2.0, 1.0]])
         q1 = a * self.ureg.meter
         q2 = a.T * self.ureg.meter
-        self.assertQuantityEqual(q1.T, q2)
+        helpers.assert_quantity_equal(q1.T, q2)
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue250(self):
         a = self.ureg.V
         b = self.ureg.mV
-        self.assertEqual(np.float16(a / b), 1000.0)
-        self.assertEqual(np.float32(a / b), 1000.0)
-        self.assertEqual(np.float64(a / b), 1000.0)
+        assert np.float16(a / b) == 1000.0
+        assert np.float32(a / b) == 1000.0
+        assert np.float64(a / b) == 1000.0
         if "float128" in dir(np):
-            self.assertEqual(np.float128(a / b), 1000.0)
+            assert np.float128(a / b) == 1000.0
 
     def test_issue252(self):
         ur = UnitRegistry()
         q = ur("3 F")
         t = copy.deepcopy(q)
         u = t.to(ur.mF)
-        self.assertQuantityEqual(q.to(ur.mF), u)
+        helpers.assert_quantity_equal(q.to(ur.mF), u)
 
     def test_issue323(self):
         from fractions import Fraction as F
 
-        self.assertEqual((self.Q_(F(2, 3), "s")).to("ms"), self.Q_(F(2000, 3), "ms"))
-        self.assertEqual((self.Q_(F(2, 3), "m")).to("km"), self.Q_(F(1, 1500), "km"))
+        assert (self.Q_(F(2, 3), "s")).to("ms") == self.Q_(F(2000, 3), "ms")
+        assert (self.Q_(F(2, 3), "m")).to("km") == self.Q_(F(1, 1500), "km")
 
     def test_issue339(self):
         q1 = self.ureg("")
-        self.assertEqual(q1.magnitude, 1)
-        self.assertEqual(q1.units, self.ureg.dimensionless)
+        assert q1.magnitude == 1
+        assert q1.units == self.ureg.dimensionless
         q2 = self.ureg("1 dimensionless")
-        self.assertEqual(q1, q2)
+        assert q1 == q2
 
     def test_issue354_356_370(self):
-        self.assertEqual(
-            "{:~}".format(1 * self.ureg.second / self.ureg.millisecond), "1.0 s / ms"
+        assert (
+            "{:~}".format(1 * self.ureg.second / self.ureg.millisecond) == "1.0 s / ms"
         )
-        self.assertEqual("{:~}".format(1 * self.ureg.count), "1 count")
-        self.assertEqual("{:~}".format(1 * self.ureg("MiB")), "1 MiB")
+        assert "{:~}".format(1 * self.ureg.count) == "1 count"
+        assert "{:~}".format(1 * self.ureg("MiB")) == "1 MiB"
 
     def test_issue468(self):
-        @ureg.wraps(("kg"), "meter")
+        @ureg.wraps("kg", "meter")
         def f(x):
             return x
 
         x = ureg.Quantity(1.0, "meter")
         y = f(x)
         z = x * y
-        self.assertEqual(z, ureg.Quantity(1.0, "meter * kilogram"))
+        assert z == ureg.Quantity(1.0, "meter * kilogram")
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue482(self):
         q = self.ureg.Quantity(1, self.ureg.dimensionless)
         qe = np.exp(q)
-        self.assertIsInstance(qe, self.ureg.Quantity)
+        assert isinstance(qe, self.ureg.Quantity)
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue483(self):
         ureg = self.ureg
         a = np.asarray([1, 2, 3])
@@ -465,19 +469,21 @@ class TestIssues(QuantityTestCase):
         battery_ec = 16 * ureg.kWh / ureg._100km  # noqa: F841
         # ... but not with text
         ureg.define("_home = 4700 * kWh / year")
-        with self.assertRaises(AttributeError):
+        with pytest.raises(AttributeError):
             home_elec_power = 1 * ureg._home  # noqa: F841
         # ... or with *only* underscores
         ureg.define("_ = 45 * km")
-        with self.assertRaises(AttributeError):
+        with pytest.raises(AttributeError):
             one_blank = 1 * ureg._  # noqa: F841
 
     def test_issue523(self):
         src, dst = UnitsContainer({"meter": 1}), UnitsContainer({"degF": 1})
         value = 10.0
         convert = self.ureg.convert
-        self.assertRaises(DimensionalityError, convert, value, src, dst)
-        self.assertRaises(DimensionalityError, convert, value, dst, src)
+        with pytest.raises(DimensionalityError):
+            convert(value, src, dst)
+        with pytest.raises(DimensionalityError):
+            convert(value, dst, src)
 
     def test_issue532(self):
         ureg = self.ureg
@@ -486,8 +492,9 @@ class TestIssues(QuantityTestCase):
         def f(x):
             return 2 * x
 
-        self.assertEqual(f(ureg.Quantity(1, "")), 2)
-        self.assertRaises(DimensionalityError, f, ureg.Quantity(1, "m"))
+        assert f(ureg.Quantity(1, "")) == 2
+        with pytest.raises(DimensionalityError):
+            f(ureg.Quantity(1, "m"))
 
     def test_issue625a(self):
         Q_ = ureg.Quantity
@@ -521,11 +528,11 @@ class TestIssues(QuantityTestCase):
         lunar_module_height = Q_(10, "m")
         t1 = calculate_time_to_fall(lunar_module_height)
         # print(t1)
-        self.assertAlmostEqual(t1, Q_(1.4285714285714286, "s"))
+        assert round(abs(t1 - Q_(1.4285714285714286, "s")), 7) == 0
 
         moon_gravity = Q_(1.625, "m/s^2")
         t2 = calculate_time_to_fall(lunar_module_height, moon_gravity)
-        self.assertAlmostEqual(t2, Q_(3.508232077228117, "s"))
+        assert round(abs(t2 - Q_(3.508232077228117, "s")), 7) == 0
 
     def test_issue625b(self):
         Q_ = ureg.Quantity
@@ -550,10 +557,10 @@ class TestIssues(QuantityTestCase):
             return time * rate
 
         d1 = get_displacement(Q_(2, "s"))
-        self.assertAlmostEqual(d1, Q_(2, "m"))
+        assert round(abs(d1 - Q_(2, "m")), 7) == 0
 
         d2 = get_displacement(Q_(2, "s"), Q_(1, "deg/s"))
-        self.assertAlmostEqual(d2, Q_(2, " deg"))
+        assert round(abs(d2 - Q_(2, " deg")), 7) == 0
 
     def test_issue625c(self):
         u = UnitRegistry()
@@ -562,18 +569,18 @@ class TestIssues(QuantityTestCase):
         def get_product(a=2 * u.m, b=3 * u.m, c=5 * u.m):
             return a * b * c
 
-        self.assertEqual(get_product(a=3 * u.m), 45 * u.m ** 3)
-        self.assertEqual(get_product(b=2 * u.m), 20 * u.m ** 3)
-        self.assertEqual(get_product(c=1 * u.dimensionless), 6 * u.m ** 2)
+        assert get_product(a=3 * u.m) == 45 * u.m ** 3
+        assert get_product(b=2 * u.m) == 20 * u.m ** 3
+        assert get_product(c=1 * u.dimensionless) == 6 * u.m ** 2
 
     def test_issue655a(self):
         distance = 1 * ureg.m
         time = 1 * ureg.s
         velocity = distance / time
-        self.assertEqual(distance.check("[length]"), True)
-        self.assertEqual(distance.check("[time]"), False)
-        self.assertEqual(velocity.check("[length] / [time]"), True)
-        self.assertEqual(velocity.check("1 / [time] * [length]"), True)
+        assert distance.check("[length]")
+        assert not distance.check("[time]")
+        assert velocity.check("[length] / [time]")
+        assert velocity.check("1 / [time] * [length]")
 
     def test_issue655b(self):
         Q_ = ureg.Quantity
@@ -586,11 +593,11 @@ class TestIssues(QuantityTestCase):
         length = Q_(1, ureg.m)
         # Assume earth gravity
         t = pendulum_period(length)
-        self.assertAlmostEqual(t, Q_("2.0064092925890407 second"))
+        assert round(abs(t - Q_("2.0064092925890407 second")), 7) == 0
         # Use moon gravity
         moon_gravity = Q_(1.625, "m/s^2")
         t = pendulum_period(length, moon_gravity)
-        self.assertAlmostEqual(t, Q_("4.928936075204336 second"))
+        assert round(abs(t - Q_("4.928936075204336 second")), 7) == 0
 
     def test_issue783(self):
         assert not ureg("g") == []
@@ -658,12 +665,12 @@ class TestIssues(QuantityTestCase):
 
     def test_issue932(self):
         q = ureg.Quantity("1 kg")
-        with self.assertRaises(DimensionalityError):
+        with pytest.raises(DimensionalityError):
             q.to("joule")
         ureg.enable_contexts("energy", *(Context() for _ in range(20)))
         q.to("joule")
         ureg.disable_contexts()
-        with self.assertRaises(DimensionalityError):
+        with pytest.raises(DimensionalityError):
             q.to("joule")
 
     def test_issue960(self):
@@ -681,10 +688,10 @@ class TestIssues(QuantityTestCase):
         q = 3 * ureg.s
         d = MultiplicativeDictionary({4: 5, 6: 7})
         assert q * d == MultiplicativeDictionary({4: 15 * ureg.s, 6: 21 * ureg.s})
-        with self.assertRaises(TypeError):
+        with pytest.raises(TypeError):
             d * q
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue973(self):
         """Verify that an empty array Quantity can be created through multiplication."""
         q0 = np.array([]) * ureg.m  # by Unit
@@ -694,14 +701,15 @@ class TestIssues(QuantityTestCase):
         assert len(q0) == len(q1) == 0
 
     def test_issue1058(self):
-        """ verify that auto-reducing quantities with three or more units
-        of same base type succeeds """
+        """verify that auto-reducing quantities with three or more units
+        of same base type succeeds"""
         q = 1 * ureg.mg / ureg.g / ureg.kg
         q.ito_reduced_units()
-        self.assertIsInstance(q, ureg.Quantity)
+        assert isinstance(q, ureg.Quantity)
 
     def test_issue1062_issue1097(self):
         # Must not be used by any other tests
+        ureg = UnitRegistry()
         assert "nanometer" not in ureg._units
         for i in range(5):
             ctx = Context.from_lines(["@context _", "cal = 4 J"])
@@ -745,7 +753,7 @@ class TestIssues(QuantityTestCase):
         ureg.enable_contexts("c2")
         ureg.enable_contexts("c3")
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue1144_1102(self):
         # Performing operations shouldn't modify the original objects
         # Issue 1144
@@ -768,13 +776,47 @@ class TestIssues(QuantityTestCase):
         q1 - q2
         assert all(q1 == ureg.Quantity([-287.78, -32.24, -1.94], ddc))
 
-    @helpers.requires_numpy()
+    @helpers.requires_numpy
     def test_issue_1136(self):
         assert (2 ** ureg.Quantity([2, 3], "") == 2 ** np.array([2, 3])).all()
 
         with pytest.raises(DimensionalityError):
             2 ** ureg.Quantity([2, 3], "m")
 
+    def test_issue1175(self):
+        import pickle
+
+        foo1 = get_application_registry().Quantity(1, "s")
+        foo2 = pickle.loads(pickle.dumps(foo1))
+        assert isinstance(foo1, foo2.__class__)
+        assert isinstance(foo2, foo1.__class__)
+
+    @helpers.requires_numpy
+    def test_issue1174(self):
+        q = [1.0, -2.0, 3.0, -4.0] * self.ureg.meter
+        assert np.sign(q[0].magnitude)
+        assert np.sign(q[1].magnitude)
+
+    @helpers.requires_numpy()
+    def test_issue_1185(self):
+        # Test __pow__
+        foo = ureg.Quantity((3, 3), "mm / cm")
+        assert np.allclose(foo ** ureg.Quantity([2, 3], ""), 0.3 ** np.array([2, 3]))
+        assert np.allclose(foo ** np.array([2, 3]), 0.3 ** np.array([2, 3]))
+        assert np.allclose(np.array([2, 3]) ** foo, np.array([2, 3]) ** 0.3)
+        # Test __ipow__
+        foo **= np.array([2, 3])
+        assert np.allclose(foo, 0.3 ** np.array([2, 3]))
+        # Test __rpow__
+        assert np.allclose(
+            np.array((1, 1)).__rpow__(ureg.Quantity((2, 3), "mm / cm")),
+            np.array((0.2, 0.3)),
+        )
+        assert np.allclose(
+            ureg.Quantity((20, 20), "mm / cm").__rpow__(np.array((0.2, 0.3))),
+            np.array((0.04, 0.09)),
+        )
+
 
 if np is not None:
 
