@@ -412,6 +412,13 @@ class UnitsContainer(Mapping):
             self._hash = hash(frozenset(self._d.items()))
         return self._hash
 
+    # Only needed by pickle protocol 0 and 1 (used by pytables)
+    def __getstate__(self):
+        return self._d, self._hash, self._one, self._non_int_type
+
+    def __setstate__(self, state):
+        self._d, self._hash, self._one, self._non_int_type = state
+
     def __eq__(self, other):
         if isinstance(other, UnitsContainer):
             # UnitsContainer.__hash__(self) is not the same as hash(self); see
@@ -424,7 +431,11 @@ class UnitsContainer(Mapping):
             other = other._d
 
         elif isinstance(other, str):
-            other = ParserHelper.from_string(other, self._non_int_type)
+            try:
+                other = ParserHelper.from_string(other, self._non_int_type)
+            except DefinitionSyntaxError:
+                return False
+
             other = other._d
 
         return dict.__eq__(self._d, other)
@@ -638,6 +649,14 @@ class ParserHelper(UnitsContainer):
             raise ValueError(mess)
         return super().__hash__()
 
+    # Only needed by pickle protocol 0 and 1 (used by pytables)
+    def __getstate__(self):
+        return super().__getstate__() + (self.scale,)
+
+    def __setstate__(self, state):
+        super().__setstate__(state[:-1])
+        self.scale = state[-1]
+
     def __eq__(self, other):
         if isinstance(other, ParserHelper):
             return self.scale == other.scale and super().__eq__(other)
